package Catmandu::BibTeX;

=head1 NAME

Catmandu::BibTeX - Catmandu modules for working with BibTeX data

=head1 VERSION

Version 0.03

=cut

our $VERSION = '0.03';

=head1 MODULES

=over

=item * L<Catmandu::Importer::BibTeX>

=item * L<Catmandu::Exporter::BibTeX>

=back

=head1 AUTHOR

Nicolas Steenlant C<< <nicolas.steenlant at ugent.be> >>

=head1 CONTRIBUTORS

Vitali Peil C<< <vitali.peil at uni-bielefeld.de> >>

=head1 LICENSE AND COPYRIGHT

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.

=cut

1;
